abacusai.audio_url_result — AbacusAI documentation

# abacusai.audio_url_result

## Classes

`AudioUrlResult` | TTS result

## Module Contents

class abacusai.audio_url_result.AudioUrlResult(client, audioUrl=None, creditsUsed=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  TTS result

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - audioUrl (str) – The audio url.

    - creditsUsed (float) – The credits used.

  audio_url = None
  credits_used = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict